.. Copyright (c) 2018, Voilà Contributors
   Copyright (c) 2018, QuantStack
   
   Distributed under the terms of the BSD 3-Clause License.
   
   The full license is in the file LICENSE, distributed with this software.

.. image:: voila-logo.svg
   :alt: voila

*From notebooks to standalone web applications and dashboards.*

Voilà allows you to convert a Jupyter Notebook into an
interactive dashboard that allows you to share your work with others. It
is secure and customizable, giving you control over what your readers
experience.

For example, here's a dashboard created with Voilà. (You can
try it interactively at the following Binder link)

.. image:: https://mybinder.org/badge_logo.svg
   :target: https://mybinder.org/v2/gh/voila-dashboards/voila/stable?urlpath=voila%2Ftree%2Fnotebooks


.. image:: ../../voila-basics.gif



Table of contents
=================

For more information about Voilà, see the sections below.

.. toctree::
   :maxdepth: 2

   install
   using
   customize
   deploy
   contribute
